﻿// ActivateOrCreateLister
// (c) 2024 Stephane

// This is a script for Directory Opus.
// See https://www.gpsoft.com.au/endpoints/redirect.php?page=scripts for development information.



// Called by Directory Opus to initialize the script
function OnInit(initData)
{
	initData.name = "ActivateOrCreateLister";
	initData.version = "1.0";
	initData.copyright = "(c) 2024 Stephane";
//	initData.url = "https://resource.dopus.com/c/buttons-scripts/16";
	initData.desc = "Search for specific lister (based on creation layout) and bring them to front when they exists or create them from that Layout";
	initData.default_enable = true;
	initData.group = "0 - Custom Scripts [SAL]";
	initData.min_version = "13.0";
}

// Called to add commands to Opus
function OnAddCommands(addCmdData)
{
	var cmd = addCmdData.AddCommand();
	cmd.name = "ActivateOrCreateLister";
	cmd.method = "OnActivateOrCreateLister";
	cmd.desc = "";
	cmd.label = "ActivateOrCreateLister";
	cmd.template = "FORCE_CREATE/S,TARGET/O[SINGLE,SAMPLES_SOFTS,NATIVE_INSTRUMENTS,TOONTRACK_MIDI_ABLETON,MUSIC_BACKUP,LOUPEDECK,CUSTOM_TARGET],CUSTOM_NAME/O";
	cmd.hide = false;
	cmd.icon = "script";
}


// Implement the OnActivateOrCreateLister command
function OnActivateOrCreateLister(scriptCmdData)
{
	var cdf = scriptCmdData.func;
	var fsu = DOpus.fsUtil;
	var forceCreate = false;

	dout("TODO: Script command actions");
	dout("Qualifiers = " + cdf.qualifiers);
	dout("Has Target = " + cdf.args.got_arg.target);
	dout("Has ForceCreate = " + cdf.args.got_arg.force_create);
	dout("ForceCreate = " + cdf.args.force_create);

	if (cdf.qualifiers.indexOf("ctrl") != -1 || cdf.args.force_create)
		forceCreate = true;

	// Prevent deselection. This this at the start so it's done even if we exit early.
	cdf.command.deselect = false;

	// What target type are we processing
	if (cdf.args.got_arg.target) dout("Target Type is = " + cdf.args.target);
	else {
		dout("No target type provided : Exiting.", true);
		return;
	}

	var layoutName = "";
	switch (cdf.args.target) {
		case "SINGLE" :
			layoutName = "MyComputer - Simple";
			break;
		case "SAMPLES_SOFTS" :
			layoutName = "Musique\\Music Production Samples & Softs";
			break;
		case "NATIVE_INSTRUMENTS" :
			layoutName = "Musique\\Native Instruments";
			break;
		case "TOONTRACK_MIDI_ABLETON" :
			layoutName = "Musique\\Toontrack MIDI Ableton";
			break;
		case "MUSIC_BACKUP" :
			layoutName = "Musique\\Music Prod Backup Management";
			break;
		case "LOUPEDECK" :
			layoutName = "Loupedeck";
			break;
		case "CUSTOM_TARGET" :
			dout("Invoking custom target.");
			if (!cdf.args.got_arg.custom_name) {
				dout(" >> When invoking 'CUSTOM_TARGET' the 'CUSTOM_NAME' must be provided. Exiting.", true);
				return;
			}
			else
			{
				layoutName = cdf.args.custom_name;
				dout(" >> Provided target = '" + layoutName + "'");
			}
			break;
			
		default:
			dout("Unsupported target '" + cdf.args.target + "'", true);
			return;
	}

	dout("Layout Name To search = " + layoutName);

	
	var foundLister = null;
	if (! forceCreate) {
		for(var eListers = new Enumerator(DOpus.listers); !eListers.atEnd(); eListers.moveNext())
		{
			var l = eListers.item();
			var layout = (l.layout == "")?"Unknown layout":l.layout;
			if (layout == layoutName) {
				dout("found layout (" + layout + ")");
				foundLister = l;
				break;
			}
		}
	}

	dout("End of loop. Found Lister ?=" + (foundLister!=null));

	if (foundLister != null) {
		cdf.command.SetSourceTab(foundLister.activetab);
		cdf.command.RunCommand('Set LISTERCMD=tofront');
	} else {
		cdf.command.RunCommand('Prefs LAYOUT="' + layoutName + '"');
	}
}


// Helper dout function
function dout(msg, error, time) {
	if (error == undefined) error = false;
	if (time == undefined) time = true;
	DOpus.output(msg, error, time);
}

